@@ -48,9 +48,11 @@ import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.ISynchronizable;
 import org.eclipse.jface.text.ITextPresentationListener;
 import org.eclipse.jface.text.ITextViewerExtension4;
+import org.eclipse.jface.text.ITextViewerExtension5;
 import org.eclipse.jface.text.IViewportListener;
 import org.eclipse.jface.text.JFaceTextUtil;
 import org.eclipse.jface.text.Position;
+import org.eclipse.jface.text.Region;
 import org.eclipse.jface.text.TextPresentation;
 import org.eclipse.jface.text.source.Annotation;
 import org.eclipse.jface.text.source.AnnotationPainter;
@@ -107,14 +109,14 @@ public class InlinedAnnotationSupport {
 					.forEachRemaining(annotation -> {
 						if (annotation instanceof LineContentAnnotation) {
 							LineContentAnnotation ann= (LineContentAnnotation) annotation;
-							StyleRange style= InlinedAnnotationDrawingStrategy.updateStyle(ann, null);
-							if (style != null) {
-								textPresentation.mergeStyleRange(style);
-							}
-						} else if (annotation instanceof LineHeaderAnnotation) {
-							LineHeaderAnnotation ann= (LineHeaderAnnotation) annotation;
-							StyleRange style= InlinedAnnotationDrawingStrategy.updateStyle(ann, null);
+							StyleRange style= ann.updateStyle(null);
 							if (style != null) {
+								if (fViewer instanceof ITextViewerExtension5) {
+									ITextViewerExtension5 projectionViewer= (ITextViewerExtension5) fViewer;
+									IRegion annotationRegion= projectionViewer.widgetRange2ModelRange(new Region(style.start, style.length));
+									style.start= annotationRegion.getOffset();
+									style.length= annotationRegion.getLength();
+								}
 								textPresentation.mergeStyleRange(style);
 							}
 						}
