@@ -333,7 +333,11 @@ public class TextSearchVisitor {
 		if (jobCount > MAX_JOBS_COUNT) {
 			jobCount= MAX_JOBS_COUNT;
 		}
-		final JobGroup jobGroup= new TextSearchJobGroup("Text Search", maxThreads, jobCount); //$NON-NLS-1$
+
+		// Seed count over 1 can cause endless waits, see bug 543629 comment 2
+		// TODO use seed = jobCount after the bug 543660 in JobGroup is fixed
+		final int seed = 1;
+		final JobGroup jobGroup = new TextSearchJobGroup("Text Search", maxThreads, seed); //$NON-NLS-1$
 		long startTime= TRACING ? System.currentTimeMillis() : 0;
 
 		Job monitorUpdateJob= new Job(SearchMessages.TextSearchVisitor_progress_updating_job) {
@@ -430,7 +434,7 @@ public class TextSearchVisitor {
 				System.out.println(Messages.format(
 						"[TextSearch] Search duration for {0} files in {1} jobs using {2} threads: {3}ms", args)); //$NON-NLS-1$
 			}
-	   }
+		}
 	}
 
 	public IStatus search(TextSearchScope scope, IProgressMonitor monitor) {
