@@ -26,12 +26,14 @@ import org.junit.runners.Suite.SuiteClasses;
 @RunWith(Suite.class)
 @SuiteClasses({
 		ChainedPreferenceStoreTest.class,
+		DocumentProviderRegistryTest.class,
 		EncodingChangeTests.class,
 		GotoLineTest.class,
 		SegmentedModeTest.class,
 		MarkerAnnotationOrderTest.class,
 		ZoomTest.class,
 		FileDocumentProviderTest.class,
+		TextFileDocumentProviderTest.class,
 		StatusEditorTest.class
 })
 public class EditorsTestSuite {
